summaryrefslogtreecommitdiff
path: root/libopie2/opiepim/core
authoreilers <eilers>2005-01-03 16:44:42 (UTC)
committer eilers <eilers>2005-01-03 16:44:42 (UTC)
commit310c7dce0c9043f66725bc79449fe958a12ad459 (patch) (side-by-side diff)
tree9d789c21b1fb88bdd8a1ad7470867b91c70276b2 /libopie2/opiepim/core
parent0b3bbec6703c021a188c865e822f536bfa3045fc (diff)
downloadopie-310c7dce0c9043f66725bc79449fe958a12ad459.zip
opie-310c7dce0c9043f66725bc79449fe958a12ad459.tar.gz
opie-310c7dce0c9043f66725bc79449fe958a12ad459.tar.bz2
Fixing stupid API documentation error.
Moving hasQuerySettings() and querySettings up to OPimAccessTemplate to be available for all frontends..
Diffstat (limited to 'libopie2/opiepim/core') (more/less context) (ignore whitespace changes)
-rw-r--r--libopie2/opiepim/core/ocontactaccess.cpp9
-rw-r--r--libopie2/opiepim/core/ocontactaccess.h15
-rw-r--r--libopie2/opiepim/core/opimaccesstemplate.h43
3 files changed, 34 insertions, 33 deletions
diff --git a/libopie2/opiepim/core/ocontactaccess.cpp b/libopie2/opiepim/core/ocontactaccess.cpp
index 9bbc820..9d18d47 100644
--- a/libopie2/opiepim/core/ocontactaccess.cpp
+++ b/libopie2/opiepim/core/ocontactaccess.cpp
@@ -120,11 +120,2 @@ bool OPimContactAccess::save ()
-const uint OPimContactAccess::querySettings()
-{
- return ( m_backEnd->querySettings() );
-}
-
-bool OPimContactAccess::hasQuerySettings ( int querySettings ) const
-{
- return ( m_backEnd->hasQuerySettings ( querySettings ) );
-}
diff --git a/libopie2/opiepim/core/ocontactaccess.h b/libopie2/opiepim/core/ocontactaccess.h
index 5051321..9a2ecaf 100644
--- a/libopie2/opiepim/core/ocontactaccess.h
+++ b/libopie2/opiepim/core/ocontactaccess.h
@@ -118,17 +118,2 @@ class OPimContactAccess: public QObject, public OPimAccessTemplate<OPimContact>
- /**
- * Return all possible settings for queryByExample().
- * @return All settings provided by the current backend
- * (i.e.: WildCards & IgnoreCase)
- * @see QuerySettings in OPimBase for details of the parameter, queryByExample()
- */
- const uint querySettings();
-
- /**
- * Check whether settings are correct for queryByExample().
- * @return <i>true</i> if the given settings are correct and possible.
- * @see QuerySettings in OPimBase for details of the parameter
- */
- bool hasQuerySettings ( int querySettings ) const;
-
/**
diff --git a/libopie2/opiepim/core/opimaccesstemplate.h b/libopie2/opiepim/core/opimaccesstemplate.h
index 3875f09..823f03d 100644
--- a/libopie2/opiepim/core/opimaccesstemplate.h
+++ b/libopie2/opiepim/core/opimaccesstemplate.h
@@ -89,2 +89,17 @@ public:
+ /**
+ * Return all possible settings for queryByExample().
+ * @return All settings provided by the current backend
+ * (i.e.: WildCards & IgnoreCase)
+ * @see QuerySettings in OPimBase for details of the parameter, queryByExample()
+ */
+ const uint querySettings();
+
+ /**
+ * Check whether settings are correct for queryByExample().
+ * @return <i>true</i> if the given settings are correct and possible.
+ * @see QuerySettings in OPimBase for details of the parameter
+ */
+ bool hasQuerySettings ( int querySettings ) const;
+
/**
@@ -94,3 +109,3 @@ public:
* as a search mask which is converted into a query regarding the querySettings. If a time period is needed
* (as for OpimBase::DateDiff), you have to use the date/time in the query object and the endperiod (the last parameter).
* @see QuerySettings in class OPimBase
@@ -98,5 +113,5 @@ public:
* @param querySettings This parameter defines what should be searched and how the query should be interpreted
* @param endperiod Defines the end of a period for some special queries.
*/
- virtual List queryByExample( const T& query, int querySettings, const QDateTime& endperiod = QDateTime() );
+ virtual List queryByExample( const T& query, int querySettings, const QDateTime& startperiod = QDateTime() );
@@ -107,3 +122,3 @@ public:
* as a search mask which is converted into a query regarding the querySettings. If a time period is needed
* (as for OpimBase::DateDiff), you have to use the date/time in the query object and the endperiod (the last parameter).
* @see QuerySettings in class OPimBase
@@ -111,5 +126,5 @@ public:
* @param querySettings This parameter defines what should be searched and how the query should be interpreted
* @param endperiod Defines the end of a period for some special queries.
*/
- virtual List queryByExample( const OPimRecord* query, int querySettings, const QDateTime& endperiod = QDateTime() );
+ virtual List queryByExample( const OPimRecord* query, int querySettings, const QDateTime& startperiod = QDateTime() );
/**
@@ -119,3 +134,3 @@ public:
* as a search mask which is converted into a query regarding the querySettings. If a time period is needed
* (as for OpimBase::DateDiff), you have to use the date/time in the query object and the endperiod (the last parameter).
* @see QuerySettings in class OPimBase
@@ -124,6 +139,6 @@ public:
* @param querySettings This parameter defines what should be searched and how the query should be interpreted
* @param endperiod Defines the end of a period for some special queries.
*/
virtual List queryByExample( const OPimAccessTemplate::List& uidlist, const T& query, int querySettings,
- const QDateTime& endperiod = QDateTime() );
+ const QDateTime& startperiod = QDateTime() );
@@ -310,2 +325,12 @@ QArray<int> OPimAccessTemplate<T>::records()const {
+template <class T>
+const uint OPimAccessTemplate<T>::querySettings(){
+ return m_backEnd->querySettings();
+}
+
+template <class T>
+bool OPimAccessTemplate<T>::hasQuerySettings ( int querySettings ) const {
+ return m_backEnd->hasQuerySettings( querySettings );
+}
+
@@ -94,3 +109,3 @@ public:
* as a search mask which is converted into a query regarding the querySettings. If a time period is needed
- * (as for OpimBase::DateDiff), you have to use the date/time in the query object and the endperiod (the last parameter).
+ * (as for OpimBase::DateDiff), you have to use the date/time in the query object and the startperiod (the last parameter).
* @see QuerySettings in class OPimBase
@@ -98,5 +113,5 @@ public:
* @param querySettings This parameter defines what should be searched and how the query should be interpreted
- * @param endperiod Defines the end of a period for some special queries.
+ * @param startperiod Defines the start of a period for some special queries.
*/
@@ -107,3 +122,3 @@ public:
* as a search mask which is converted into a query regarding the querySettings. If a time period is needed
- * (as for OpimBase::DateDiff), you have to use the date/time in the query object and the endperiod (the last parameter).
+ * (as for OpimBase::DateDiff), you have to use the date/time in the query object and the startperiod (the last parameter).
* @see QuerySettings in class OPimBase
@@ -111,5 +126,5 @@ public:
* @param querySettings This parameter defines what should be searched and how the query should be interpreted
- * @param endperiod Defines the end of a period for some special queries.
+ * @param startperiod Defines the start of a period for some special queries.
*/
@@ -119,3 +134,3 @@ public:
* as a search mask which is converted into a query regarding the querySettings. If a time period is needed
- * (as for OpimBase::DateDiff), you have to use the date/time in the query object and the endperiod (the last parameter).
+ * (as for OpimBase::DateDiff), you have to use the date/time in the query object and the startperiod (the last parameter).
* @see QuerySettings in class OPimBase
@@ -124,6 +139,6 @@ public:
* @param querySettings This parameter defines what should be searched and how the query should be interpreted
- * @param endperiod Defines the end of a period for some special queries.
+ * @param startperiod Defines the start of a period for some special queries.
*/
virtual List queryByExample( const OPimAccessTemplate::List& uidlist, const T& query, int querySettings,